Exports

Struct Exports 

pub struct Exports<'a, P> { /* private fields */ }
Export directory.

For more information see the module-level documentation.

Implementations

Source

impl<'a, P: Pe<'a>> Exports<'a, P>

pub fn pe(&self) -> P

Gets the PE instance.

pub fn image(&self) -> &'a IMAGE_EXPORT_DIRECTORY

Returns the underlying export directory image.

pub fn dll_name(&self) -> Result<&'a CStr>

Gets the export directory’s name for this library.

pub fn ordinal_base(&self) -> Ordinal

Gets the ordinal base for the exported functions.

pub fn functions(&self) -> Result<&'a [Rva]>

Gets the export address table.

pub fn names(&self) -> Result<&'a [Rva]>

Gets the name address table.

The values are RVAs to the exported function’s name, to find its export look at the name index table with the same index.

The names are sorted allowing binary search lookup.

pub fn name_indices(&self) -> Result<&'a [u16]>

Gets the name index table.

The values are indices (not ordinals!) into the export address table matching name with the same index in the name address table.

pub fn by(&self) -> Result<By<'a, P>>

Query the exports.

This specifically validates whether the functions, names and name indices are valid.