pub trait GetProcAddress<'a, T>: Pe<'a> {
// Required method
fn get_export(self, name: T) -> Result<Export<'a>>;
// Provided method
fn get_proc_address(self, name: T) -> Result<Va> { ... }
}Expand description
Convenient way to get an exported address.
Required Methods
Sourcefn get_export(self, name: T) -> Result<Export<'a>>
fn get_export(self, name: T) -> Result<Export<'a>>
Convenient method to get an exported function.
Note that calling this method many times is less efficient than caching a By instance, such is the trade-off for convenience.
Provided Methods
Sourcefn get_proc_address(self, name: T) -> Result<Va>
fn get_proc_address(self, name: T) -> Result<Va>
Convenient method to get the address of an exported function.
Note that this method does not support forwarded exports and will return Err(Null) instead.
Note that calling this method many times is less efficient than caching a By instance, such is the trade-off for convenience.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.